@@ -1,28 +1,26 @@
 # -*- coding: utf-8 -*-
 
-
-from time import sleep
 import errno
 import os
 import socket
 import sys
 import threading
+from time import sleep
 
+from DisplayCAL import (
+    config,
+    localization as lang,
+)
 from DisplayCAL.config import confighome, getcfg, geticon, initcfg, setcfg, writecfg
 from DisplayCAL.meta import name as appname
 from DisplayCAL.util_str import safe_str, universal_newlines
 from DisplayCAL.wexpect import split_command_line
-
-# from wexpect import split_command_line
 from DisplayCAL.wxaddons import wx
 from DisplayCAL.wxfixes import GenBitmapButton
 from DisplayCAL.wxwindows import BaseApp, SimpleTerminal, numpad_keycodes
-from DisplayCAL import config
-from DisplayCAL import localization as lang
 
 import wx.lib.delayedresult as delayedresult
 
-
 ERRORCOLOR = "#FF3300"
 RESPONSECOLOR = "#CCCCCC"
 
