@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import os
+import platform
 import re
 import shutil
 import sys
@@ -468,16 +469,14 @@ else:
     wx_Panel = wx.Panel
 
 
-wx.BitmapButton._SetBitmapLabel = wx.BitmapButton.SetBitmapLabel
-
+wx.AnyButton._SetBitmapLabel = wx.AnyButton.SetBitmapLabel
 
 def SetBitmapLabel(self, bitmap):
-    """Replacement for SetBitmapLabel which avoids flickering"""
+    """Override the SetBitmapLabel to avoid flickering."""
     if self.GetBitmapLabel() != bitmap:
-        self._SetBitmapLabel(bitmap)
+        self._SetBitmapLabel(self, bitmap)
 
-
-wx.BitmapButton.SetBitmapLabel = SetBitmapLabel
+wx.AnyButton.SetBitmapLabel = SetBitmapLabel
 
 
 def BitmapButtonEnable(self, enable=True):
@@ -982,15 +981,16 @@ def set_bitmap_labels(btn, disabled=True, focus=None, pressed=True):
         if -1 in size:
             size = (16, 16)
         bitmap = wx.ArtProvider.GetBitmap(wx.ART_MISSING_IMAGE, size=size)
+        # Ensure the normal bitmap is set first, fixes #507
+        btn.SetBitmapLabel(bitmap)
 
     # Disabled
     if disabled:
+        disabled_bitmap = get_bitmap_disabled(bitmap)
         try:
-            btn.SetBitmapDisabled(get_bitmap_disabled(bitmap))
+            btn.SetBitmapDisabled(disabled_bitmap)
         except wx._core.wxAssertionError:
-            # must set normal bitmap first, fixes #507
-            btn.SetBitmapLabel(bitmap)
-            btn.SetBitmapDisabled(get_bitmap_disabled(bitmap))
+            pass
 
     # Focus/Hover
     if sys.platform != "darwin" and focus is not False:
@@ -1001,10 +1001,16 @@ def set_bitmap_labels(btn, disabled=True, focus=None, pressed=True):
         else:
             # Use focus bitmap
             bmp = get_bitmap_focus(bitmap)
-        btn.SetBitmapFocus(bmp)
+        try:
+            btn.SetBitmapFocus(bmp)
+        except wx._core.wxAssertionError:
+            pass
         if hasattr(btn, "SetBitmapCurrent"):
             # Phoenix
-            btn.SetBitmapCurrent(bmp)
+            try:
+                btn.SetBitmapCurrent(bmp)
+            except wx._core.wxAssertionError:
+               pass
         else:
             # Classic
             btn.SetBitmapHover(bmp)
@@ -1017,7 +1023,10 @@ def set_bitmap_labels(btn, disabled=True, focus=None, pressed=True):
             bmp = get_bitmap_pressed(bitmap)
         if hasattr(btn, "SetBitmapPressed"):
             # Phoenix
-            btn.SetBitmapPressed(bmp)
+            try:
+                btn.SetBitmapPressed(bmp)
+            except wx._core.wxAssertionError:
+                pass
         else:
             # Classic
             btn.SetBitmapSelected(bmp)
